@@ -213,7 +213,7 @@ class Command(BaseCommand):
 
                     print "Haciendo thumb 200x200"
                     im = get_thumbnail(im, "200x200")
-                    if p.image.width > 750 and p.image.height > 750:
+                    if im.width > 750 and im.height > 750:
                         print "Haciendo thumb 750x750"
                         im = get_thumbnail(im, "750x750")
                 total += 1
