@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from django.conf.urls.defaults import *
-from rgallery.views import Photos, Videos
+from rgallery.views import Photos, Videos, PhotosFolder
 
 urlpatterns = patterns('',
     url(r'^$', Photos.as_view(), name='app_gallery-gallery'),
